aboutsummaryrefslogtreecommitdiffstats
path: root/libmaple/dac.h
diff options
context:
space:
mode:
Diffstat (limited to 'libmaple/dac.h')
-rw-r--r--libmaple/dac.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libmaple/dac.h b/libmaple/dac.h
index bc64324..c897bb2 100644
--- a/libmaple/dac.h
+++ b/libmaple/dac.h
@@ -25,9 +25,10 @@
/**
* @file dac.h
* @brief Digital to analog converter header file
- * See notes/dac.txt for more info
*/
+/* See notes/dac.txt for more info */
+
#ifndef _DAC_H_
#define _DAC_H_
@@ -63,16 +64,15 @@ typedef struct dac_reg_map {
__io uint32 DOR2; /**< Channel 2 data output register */
} dac_reg_map;
+/** DAC device type. */
typedef struct dac_dev {
- dac_reg_map *regs;
+ dac_reg_map *regs; /**< Register map */
} dac_dev;
/** DAC device. */
extern const dac_dev *DAC;
/*
* DAC peripheral base address
*/
#define DAC_BASE ((dac_reg_map*)0x40007400)
/*
@@ -63,16 +64,15 @@ typedef struct dac_reg_map {
/** DAC device. */
extern const dac_dev *DAC;
-/*
- * DAC peripheral base address
- */
+/** DAC register map base address */
#define DAC_BASE ((dac_reg_map*)0x40007400)
/*